function [gp] = sub_geopot(S,T,P)
%
% SUB_GEOPOT    Geopotencijal
% racuna dinamicke dubine izobarnih ploha u odnosu na povrsinu
%=========================================================================
%
% upotreba:  [gp]= sub_geopot(S,T,P)
%
% OPIS:
%   Dinamicka dubina neke izobarne plohe u odnosu na povrsinu, izracunata kao integral specificnog volumena, od povrsine do izobarne plohe (dubine)
%   Dakle dinamicka dubina u odnosu na povrsinu, odn. dinamicka topografija povrsine u odnosu na izobarnu plohu.
%
% ULAZ:  (sve varijable moraju biti istih dimenzija)
%   S = salinitet    [psu      (PSS-78)]
%   T = temperatura [stupnjrvi C (ITP-68)]
%   P = Tlak    [db]
%       (P moze imati dimenzije 1x1, mx1, 1xn ili mxn za S(mxn) )
%
% IZLAZ:
%  gp = Geopotencijal  [m^3 kg^-1 Pa == m^2 s^-2 == J kg^-1]
%
% AUTOR: Mira Pasaric: 30/11/2004,
% prilagodbom sw_gpan, autora:  Phil Morgan 92-11-05  (morgan@ml.csiro.au)
%
% LITERATURA: S. Pond & G.Pickard  2nd Edition 1986
%            Introductory Dynamical Oceanogrpahy
%            Pergamon Press Sydney.  ISBN 0-08-028728-X
%
% Adapted method from Pond and Pickard (p76) to calc gpan rel to sea 
% surface whereas P&P calculated relative to the deepest common depth.
%=========================================================================
% POZIVA POTPROGRAM: sw_dens.m 

%----------------------
% CHECK INPUT ARGUMENTS
%----------------------
if nargin ~=3
   error('sw_gpan.m: Must pass 3 parameters')
end %if

% CHECK S,T,P dimensions and verify consistent
[ms,ns] = size(S);
[mt,nt] = size(T);
[mp,np] = size(P);

% CHECK THAT S & T HAVE SAME SHAPE
if (ms~=mt) | (ns~=nt)
   error('check_stp: S & T must have same dimensions')
end %if

% CHECK OPTIONAL SHAPES FOR P
if     mp==1  & np==1      % P is a scalar.  Fill to size of S
   P = P(1)*ones(ms,ns);
elseif np==ns & mp==1      % P is row vector with same cols as S
   P = P( ones(1,ms), : ); %   Copy down each column.
elseif mp==ms & np==1      % P is column vector
   P = P( :, ones(1,ns) ); %   Copy across each row
elseif mp==ms & np==ns     % PR is a matrix size(S)
   % shape ok 
else
   error('check_stp: P has wrong dimensions')
end %if
[mp,np] = size(P);
 
% IF ALL ROW VECTORS ARE PASSED THEN LET US PRESERVE SHAPE ON RETURN.
Transpose = 0;
if mp == 1  % row vector
   P       =  P(:);
   T       =  T(:);
   S       =  S(:);   

   Transpose = 1;
end %if
%***check_stp

%------
% BEGIN
%------
db2Pascal  = 1e4;
[m,n]      = size(P);
dens = sw_dens(S,T,P);              % racunanje gustoce pomocu jednadzbe stanja
svol = 1./dens;                            % specificni volumen
mean_svol  = 0.5*(svol(2:m,:) + svol(1:m-1,:) );            % srednji spec. volumen po slojevima

if n==1
   top = svol(1,1).*P(1,1)*db2Pascal;
else
   top = svol(1,:).*P(1,:)*db2Pascal;
end %if

delta_gp   = (mean_svol.*diff(P))*db2Pascal;            % razlika geopotencijala medju susjednim slojevima
gp         = cumsum([ top; delta_gp]);                       % geopotencijal povrsine u odnosu na izobarne plohe
if Transpose
   gp = gp';
end %if

return
%--------------------------------------------------------------------
